@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: conduit-extra
-version: 1.1.9.2
-id: conduit-extra-1.1.9.2-aa4a80a63306500e6d6a1edce4badfdd
-key: condu_LLZ5nhWvbDlGRYEOrOBTGU
+version: 1.1.11
+id: conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
+key: condu_5b3gTpaqLvlJEVDxa8oIzk
 license: MIT
 maintainer: michael@snoyman.com
 homepage: http://github.com/snoyberg/conduit
@@ -20,25 +20,26 @@ exposed-modules:
     Data.Conduit.Process Data.Conduit.Text Data.Conduit.Zlib
     Data.Conduit.Network.Unix
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.9.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.9.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-extra-1.1.9.2
-hs-libraries: HSconduit-extra-1.1.9.2-LLZ5nhWvbDlGRYEOrOBTGU
+import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.11
+library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.11
+data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-extra-1.1.11
+hs-libraries: HSconduit-extra-1.1.11-5b3gTpaqLvlJEVDxa8oIzk
 depends:
-    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
+    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
+    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
-    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
-    streaming-commons-0.1.15-43ddfb983feecf5e5c9c7ab99b5e44ed
+    streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
